# turkcepyallcommands

Python fonksiyonlarını Türkçeye çeviren modül.

## Kurulum

```bash
pip install pip install turkcepyallcommands==1.0.0

KULLANIM:

from turkcepython import *

çıktı("Merhaba Dünya!")
